==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/kbibtexfieldlistviewitem.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#include <qstring.h>

#include <bibtexentryfield.h>
#include "kbibtexfieldlistviewitem.h"

KBibTeXFieldListViewItem::KBibTeXFieldListViewItem( BibTeXEntryField* field, QListView *parent, const char* name )
        : QListViewItem( parent, name ), m_field( field )
{
    setTexts();
}


KBibTeXFieldListViewItem::~KBibTeXFieldListViewItem()
{
    // TODO
}

BibTeXEntryField* KBibTeXFieldListViewItem::field()
{
    return m_field;
}

void KBibTeXFieldListViewItem::updateItem()
{
    setTexts();
}

void KBibTeXFieldListViewItem::setTexts()
{
    setText( 0, m_field->key() );
    setText( 1, m_field->value() );
}

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/kbibtexfieldlistviewitem.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#include <qstring.h>

#include <bibtexentryfield.h>
#include "kbibtexfieldlistviewitem.h"

KBibTeXFieldListViewItem::KBibTeXFieldListViewItem( BibTeX::BibTeXEntryField* field, QListView *parent, const char* name )
        : QListViewItem( parent, name ), m_field( field )
{
    setTexts();
}


KBibTeXFieldListViewItem::~KBibTeXFieldListViewItem()
{
    // nothing
}

BibTeX::BibTeXEntryField* KBibTeXFieldListViewItem::field()
{
    return m_field;
}

void KBibTeXFieldListViewItem::updateItem()
{
    setTexts();
}

void KBibTeXFieldListViewItem::setTexts()
{
    setText( 0, m_field->fieldTypeName() );
    if ( m_field->begin() != m_field->end() )
        setText( 1, ( ( BibTeX::BibTeXElement::FieldItem ) * ( m_field->begin() ) ).text );
}
